@@ -9,12 +9,12 @@ from worker.event.stream import StreamEvent
 from worker.framework import constants
 from worker.mixins.logging import LoggingMixin
 from worker.mixins.rollbar import RollbarMixin
-from worker.state.mixins import StateMixin
+from worker.state.mixins import RedisMixin
 from worker.state.state import State
 from worker import exceptions
 
 
-class App(StateMixin, LoggingMixin, RollbarMixin):
+class App(RedisMixin, LoggingMixin, RollbarMixin):
     """
     The apps is designed to receive the events of a single asset
     """
@@ -28,11 +28,6 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         self.app_name = constants.get('global.app-name')
         self.module_key = None
 
-        state_storage_type = constants.get("global.state_storage_type", None)
-        if state_storage_type is not None:
-            # Add to kwargs if defined in constants, else will get from environment
-            kwargs["state_storage_type"] = state_storage_type
-
         self.event_type: EventType = None
 
         self.asset_id = None
@@ -42,6 +37,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
     def load(self, event_type: EventType, event: Event):
         """
+        :param event_type:
         :param event: a scheduler event or wits stream
         :return:
         """
@@ -219,8 +215,8 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         except Exception:
             raise Exception('Event does not contain asset_id: {}'.format(event))
 
-    def load_state(self, state_key: Union[str, None] = None, auto_migrate: bool = False, raise_warnings: bool = False) -> dict:
-        previous_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate, raise_warnings=raise_warnings)
+    def load_state(self, state_key: Union[str, None] = None, raise_warnings: bool = False) -> dict:
+        previous_state = super().load_state(state_key=state_key, raise_warnings=raise_warnings)
 
         state = State(self.app_state_fields, previous_state)
 
@@ -229,12 +225,6 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         return state
 
-    def save_state(self, state_key: Union[str, None] = None, timestamp: Union[int, None] = None, raise_warnings: bool = True) -> None:
-        if not timestamp:
-            timestamp = self.state.get('last_processed_timestamp', 0)
-
-        super().save_state(state_key=state_key, timestamp=timestamp, raise_warnings=raise_warnings)
-
     def get_modules(self) -> List[Module]:
         raise NotImplementedError("No modules found")
 
