@@ -38,7 +38,8 @@ class Wellbore:
         self.original_drillstring: Drillstring = kwargs.get('original_drillstring') or kwargs.get('drillstring')
         self.actual_drillstring: Drillstring = kwargs.get('actual_drillstring')
 
-        self.original_hole: Hole = kwargs.get('original_hole') or kwargs.get('hole')
+        # Explicitly checking if original_hole is not None, because bool of Hole with no sections evaluates to False
+        self.original_hole: Hole = kwargs.get('original_hole') if kwargs.get('original_hole') is not None else kwargs.get('hole')
         self.actual_hole: Hole = kwargs.get('actual_hole')
 
         self.actual_annulus: Annulus = kwargs.get('actual_annulus')
